"""
wire-band-edge
==============

Lightweight Wire.Band client for gateway hardware — Raspberry Pi, NVIDIA Jetson,
industrial PCs, any Linux SBC.

Zero dependencies on private packages. Install on any device with:

    pip install wire-band-edge            # MQTT bridge
    pip install wire-band-edge[mqtt]      # + aiomqtt broker support

Usage:

    from wire_band_edge import WireBandEdgeClient, MQTTConnector

    async def main():
        client = WireBandEdgeClient(
            backend_url="http://your-wireband-server:8000",
            device_id="robot-arm-01",
            delta_threshold=0.02,
        )
        connector = MQTTConnector("mqtt://localhost:1883")
        await client.run_mqtt(connector, topics=["sensors/#", "robot/#"])

    asyncio.run(main())
"""

from .edge_client import WireBandEdgeClient, BufferedEvent
from .mqtt_connector import MQTTConnector, MQTTEvent, MQTTTopicClassifier

__version__ = "0.1.0"

__all__ = [
    "WireBandEdgeClient",
    "BufferedEvent",
    "MQTTConnector",
    "MQTTEvent",
    "MQTTTopicClassifier",
]
